@@ -10,8 +10,9 @@ import itertools
 import operator
 
 import statushandler
-from haystack import memory_dumper
-from haystack import memory_mapping
+from .. import memory_dumper
+from .. import memory_mapping
+from .. import signature
 
 log = logging.getLogger('gui')
 
@@ -22,7 +23,7 @@ import widgets
 import infomodel
 from memmaptab import Ui_MemoryMappingWidget
 from mainwindow import Ui_MainWindow
-
+import searchinfoview
 
 try:
     _fromUtf8 = QtCore.QString.fromUtf8
@@ -97,6 +98,9 @@ class MemoryMappingWidget(QtGui.QWidget, Ui_MemoryMappingWidget):
     self.gridLayout.addWidget(self.splitter, 0, 0, 1, 2)    
     self.splitter.setSizePolicy(sizePolicy) # resize
     self.splitter.setObjectName(_fromUtf8("splitter_graphics_info"))
+    #
+    while self.tab_search_structures.count() > 0:
+      self.tab_search_structures.removeItem(0)    
     # mine
     self.pointers = None
     self.nullWords = None
@@ -157,15 +161,12 @@ class MemoryMappingWidget(QtGui.QWidget, Ui_MemoryMappingWidget):
     self.pointers = QtGui.QGraphicsItemGroup(scene=self.scene) 
     log.info('search %s mapping for pointer'%(self.mapping_name))
     found = 0 
-    for offset in xrange(0,len(self.mapping),4):
-      if offset%1024:
-        log.info('searching pointers at @0x%x'%(offset+self.mapping.start))
-      i = offset + self.mapping.start
-      word = self.mapping.readWord(i)
-      # find pointers
-      if word in self.mapping:
-        found +=1
-        self.pointers.addToGroup(widgets.Word(offset,word,scene = self.scene, color = QtCore.Qt.red) )
+    start = self.mapping.start
+    searcher = signature.PointerSearcher(self.mapping)
+    for vaddr in searcher:
+      word = self.mapping.readWord(vaddr)
+      offset = vaddr - start
+      self.pointers.addToGroup(widgets.Word(offset, word, scene = self.scene, color = QtCore.Qt.red) )
     # fill the scene
     self.scene.addItem(self.pointers)
     self.pointers.hide()
@@ -178,12 +179,12 @@ class MemoryMappingWidget(QtGui.QWidget, Ui_MemoryMappingWidget):
     log.info('search %s mapping for null words'%(self.mapping_name))
     found = 0 
     tmpnull = []
-    for offset in xrange(0, len(self.mapping), 4):
-      i = offset + self.mapping.start
-      word = self.mapping.readWord(i)
-      if word == 0: # find null values
-        tmpnull.append(offset/4) # save offset aligned indices, cause i don't get "lambda (i,x):i-x" . Shame on me.
-    # filter and 
+    start = self.mapping.start
+    searcher = signature.NullSearcher(self.mapping)
+    for vaddr in searcher:
+      offset = vaddr - start
+      tmpnull.append(offset/searcher.WORDSIZE)
+    # filter and regroup null word by bunches
     nb = 0
     should = 0
     for k, g in itertools.groupby(enumerate(tmpnull), lambda (i,x):i-x):
@@ -210,26 +211,34 @@ class MemoryMappingWidget(QtGui.QWidget, Ui_MemoryMappingWidget):
     from haystack import abouchet
     import ctypes
     #import sslsnoop #?
-    instances = abouchet.searchIn(structType, mappings=self.mappings, targetMappings=[self.mapping] ,maxNum=5)
+    #self.mapping.unmmap()
+    # DEBUG stop at the first instance, lazy me  
+    instances = abouchet.searchIn(structType, mappings=self.mappings, targetMappings=[self.mapping], maxNum=1)
     if len(instances) > 0:
       log.debug('received %d struct of size %d'%(len(instances),len(instances[0][0])))
     # init graphical element
-    instanceList = []
+    resultsViewer = searchinfoview.SearchInfoView(self.scene, QtCore.Qt.green, withDetails=True, parent=self.tab_search_structures)
     for value, addr in instances:
       offset = addr - self.mapping.start
-      instanceList.append(widgets.Structure( offset, value, color=QtCore.Qt.green, scene=self.scene))
+      #instanceList.append(widgets.Structure( offset, value, color=QtCore.Qt.green, scene=self.scene))
+      log.debug('the value is an %s'%type(value) )
+      resultsViewer.addResult( offset, value, color=QtCore.Qt.green)
     # fill the scene
-    #self.scene.addItem(instanceList)
     log.debug('Found %d instances'%(len(instances)) )
-    gitemgroup = QtGui.QGraphicsItemGroup(scene=self.scene)
-    for s in instanceList:
-      gitemgroup.addToGroup(s)
-    gitemgroup.setZValue(20) # zValue has to be  > 0
+    #gitemgroup = QtGui.QGraphicsItemGroup(scene=self.scene)
+    #for s in instanceList:
+    #  gitemgroup.addToGroup(s)
+    #gitemgroup.setZValue(20) # zValue has to be  > 0
     # add self.instanceList to
-    if len(instanceList) >0 :
-      self.showInfo(instanceList[0])
-    return instanceList,gitemgroup
-
+    #if len(instanceList) >0 :
+    #  self.showInfo(instanceList[0])
+    ## make the toolbox title and add the widget
+    searchName = 'Results for %s'%(structType)
+    self.tab_search_structures.addItem(resultsViewer, searchName)
+    nb = self.tab_search_structures.count()
+    ##self.tab_search_structures.setItemEnabled(nb-1, True)
+    return instances
+  '''
   def showInfo(self, structure):
     log.info('show info on %s'%(structure))
     pyObj = structure.value
@@ -257,6 +266,23 @@ class MemoryMappingWidget(QtGui.QWidget, Ui_MemoryMappingWidget):
     # enable sorting
     self.info_tableview.setSortingEnabled(True)
     return
+  '''
+  def search_regexp(self, regexp, searchName, color=QtCore.Qt.black):
+    reSearcher = signature.RegexpSearcher(self.mapping, regexp)
+    # add a entry into the tabView on the right so we can play with it more easily
+    resultsViewer = searchinfoview.SearchInfoView(self.scene, color, parent=self.tab_search_structures)
+    res=[]
+    for addr, value in reSearcher:
+      offset = addr-self.mapping.start
+      # add item to viewer + graphicsScene
+      it = resultsViewer.addResult( offset, value, color)
+      res.append(it)
+    self.tab_search_structures.addItem(resultsViewer, searchName)
+    nb = self.tab_search_structures.count()
+    self.tab_search_structures.setItemEnabled(nb-1, True)
+    # resize 
+    #self.tab_search_structures
+    return res
 
 
 
@@ -411,7 +437,8 @@ def main(argv):
   logging.basicConfig(level=logging.DEBUG)
   logging.getLogger('haystack').setLevel(logging.INFO)
   logging.getLogger('model').setLevel(logging.INFO)
-  logging.getLogger('widget').setLevel(logging.INFO)
+  logging.getLogger('dumper').setLevel(logging.INFO)
+  #logging.getLogger('widget').setLevel(logging.INFO)
   logging.getLogger('ctypes_openssh').setLevel(logging.INFO)
   logging.getLogger('widget').setLevel(logging.INFO)
   logging.getLogger('gui').setLevel(logging.INFO)
