@@ -13,11 +13,11 @@ from PyQt4.Qt import Qt
 
 from haystack import model
 
-#LINE_SIZE=512
-#PAGE_SIZE=4096 
+LINE_SIZE=512
+PAGE_SIZE=4096 
 
-LINE_SIZE=512*4
-PAGE_SIZE=4096*16 
+#LINE_SIZE=512*4
+#PAGE_SIZE=4096*16 
 
 class MemoryMappingScene(QtGui.QGraphicsScene):
   ''' 
@@ -160,20 +160,27 @@ class MemoryMappingView(QtGui.QGraphicsView):
     pitem = item.parentItem()
     if pitem is None:
       # no parent item, that must be lonely....
-      if self.mapping:
+      if self.mapping :
         # read mapping value 
         addr = event.pos().y()* LINE_SIZE + event.pos().x()
         value = self.mapping.readWord(self.mapping.start+addr)
-        log.debug('@0x%x: 0x%x'%(self.mapping.start+addr,value))
+        log.debug('@0x%x: 0x%x'%(self.mapping.start+addr,value))      
     else:
-      # parent item, check for types
-      if hasattr(item,'value') and model.isRegistered(item.value):
-        log.debug('showing info for %s'%(item))
+      # parent item, check for haystack types
+      log.debug('Mouse press on parent item '+str(pitem))
+      if hasattr(pitem,'value') and model.isRegistered(pitem.value):
+        log.debug('showing info for %s'%(pitem))
         # update info view
-        self.parent().showInfo(item)
-      else:
+        self.parent().showInfo(pitem)
+      elif hasattr(pitem, 'onSelect' ):
         # print status for pointers and nulls
-        log.debug(pitem)
+        log.debug('running parent onSelect')
+        pitem.onSelect()
+      elif hasattr(item, 'onSelect' ):
+        log.debug('running item onSelect')
+        pitem.onSelect()
+      else:
+        log.debug('%s has no onSelect method'%item)
       
     return
  
