@@ -12,6 +12,15 @@ import os
 import logging
 log = logging.getLogger('memory_mapping')
 
+'''
+Memory mappings.
+- MemoryMapping : memory space from a live process with the possibility to mmap the memspace at any moment.
+- MemoryDumpMemoryMapping : memory space dumped to a raw file. 
+- FileMemoryMapping : tool to initialize an existing memory mapping from the content of a file/tarfilecontent backup memory dump.
+- FileBackedMemoryMapping/getFileBackedMemoryMapping : memory space based on a file, with direct read no cache from file.
+'''
+
+
 PROC_MAP_REGEX = re.compile(
     # Address range: '08048000-080b0000 '
     r'([0-9a-f]+)-([0-9a-f]+) '
@@ -268,11 +277,11 @@ def fileMemoryMapping_process(self):
   if self._local_mmap is None:
     if hasattr(self.memdump,'fileno'):
       self._local_mmap = mmap.mmap(self.memdump.fileno(), self.end-self.start, access=mmap.ACCESS_READ)
-      log.info('Lazy Memory Mapping content mmap-ed() : %s'%(self))
+      log.debug('Lazy Memory Mapping content mmap-ed() : %s'%(self))
     else:
       # use that or mmap, anyway, we need to convert to ctypes :/ that costly
       self._local_mmap = model.bytes2array(self.memdump.read(), ctypes.c_ubyte)
-      log.info('Lazy Memory Mapping content loaded : %s'%(self))
+      log.debug('Lazy Memory Mapping content loaded : %s'%(self))
   return self
 
 def FileMemoryMapping(memoryMapping, memdump):
@@ -370,6 +379,8 @@ class FileBackedMemoryMapping(MemoryDumpMemoryMapping):
     array = (basetype *count).from_buffer_copy(self._local_mmap[laddr:laddr+size], 0)
     return array
 
+
+
 def readProcessMappings(process):
     """
     Read all memory mappings of the specified process.
